get_animated_properties

Function get_animated_properties 

fn get_animated_properties(
    keyframes: &[Arc<Locked<Keyframe>>],
    guard: &SharedRwLockReadGuard<'_>,
) -> AnimatedProperties
Returns an AnimatedProperties for the animated properties in a keyframes animation. In Gecko that only has a bool tracking if there is any such property, while Servo tracks the set of all these properties.