pub struct KeyframeSelector {
range_name: TimelineRangeName,
percentage: KeyframePercentage,
}Expand description
A single <keyframe-selector>:
<keyframe-selector> = from | to | <percentage [0,100]> | <timeline-range-name> <percentage>
It could be a percentage, from/to, or a timeline range name together with a percentage.
https://drafts.csswg.org/scroll-animations-1/#named-range-keyframes
Fields
range_name: TimelineRangeNameThe named timeline range name component of the selector. If it is omitted, we use
TimelineRangeName::None. Note that TimelineRangeName::Normal is not used for the
selector.
percentage: KeyframePercentageThe percentage component of the selector. It is a percentage or a from/to symbol, which is converted at parse time to percentage.
Implementations
Sourceimpl KeyframeSelector
impl KeyframeSelector
Sourcefn new_for_unit_testing(percentage: KeyframePercentage) -> Self
fn new_for_unit_testing(percentage: KeyframePercentage) -> Self
Returns Self as a percentage, for unit testing.
Sourcepub fn parse<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>>
pub fn parse<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>>
Parse a keyframe selector from CSS input.