fn get_animated_properties(
keyframes: &[Arc<Locked<Keyframe>>],
guard: &SharedRwLockReadGuard<'_>,
) -> AnimatedPropertiesExpand description
Returns an AnimatedProperties for the animated properties in a keyframes animation.
In Gecko that only has a bool tracking if there is any such property, while Servo
tracks the set of all these properties.