fn has_animated_properties(
keyframes: &[Arc<Locked<Keyframe>>],
guard: &SharedRwLockReadGuard<'_>,
properties_changed: Option<&mut PropertyDeclarationIdSet>,
) -> boolExpand description
True if there are any animated properties in a keyframes animation. If a PropertyDeclarationIdSet is provided, it will be populated with the animated properties.